@@ -4,47 +4,44 @@
 """HdfsCLI: a command line interface for WebHDFS.
 
 Usage:
-  hdfs [-a ALIAS] [--info] [-j] [-d DEPTH] [PATH]
-  hdfs [-a ALIAS] --read PATH
-  hdfs [-a ALIAS] --write [-o] PATH
-  hdfs [-a ALIAS] --download [-o] [-t THREADS] PATH LOCALPATH
-  hdfs -h | --help | -v | --version
+  hdfs [-a ALIAS] [--info] [-j] [-d DEPTH] [RPATH]
+  hdfs [-a ALIAS] --read RPATH
+  hdfs [-a ALIAS] --write [-o] RPATH
+  hdfs [-a ALIAS] --download [-o] [-t THREADS] RPATH LPATH
+  hdfs -h | --help | -l | --log | -v | --version
 
 Commands:
+  --download                    Download a (potentially distributed) file from
+                                HDFS into `LPATH`.
   --info                        View information about files and directories.
-                                This is the default command.
-  --read                        Read a file from HDFS to standard out. If
-                                `PATH` is a directory, this command will
-                                attempt to read (in order) any part-files found
-                                directly under it.
-  --download                    Download a file from HDFS into `LOCALPATH`. If 
-                                `PATH` is a directory, attempt to download all 
-                                part-files found in it into `LOCALPATH`.
-  --write                       Write from standard in to HDFS.
+  --read                        Read a file from HDFS to standard out. Note
+                                that this only works for normal files.
+  --write                       Write from standard in to a path on HDFS.
 
 Arguments:
-  PATH                          Remote HDFS path.
-  LOCALPATH                     Local file or directory for downloading. 
+  LPATH                         Path to local file or directory.
+  RPATH                         Remote HDFS path.
 
 Options:
-  -a ALIAS --alias=ALIAS        Alias, defaults to alias pointed to by 
+  -a ALIAS --alias=ALIAS        Alias, defaults to alias pointed to by
                                 `default.alias` in ~/.hdfsrc.
   -d DEPTH --depth=DEPTH        Maximum depth to explore directories. Specify
                                 `-1` for no limit [default: 0].
-  -o --overwrite                'Smart' mode overwrite: Overwrite existing files
-                                at target location whose timestamps are newer 
-                                than source files or if file sizes do not match.
+  -l --log                      Show path to current log file and exit.
   -h --help                     Show this message and exit.
   -j --json                     Output JSON instead of tab delimited data.
-  -t THREADS --threads=THREADS  Number of threads to use for downloading part-
-                                files. `-1` allocates a thread per part-file
-                                while `1` disables parallelization [default: 1].
+  -o --overwrite                Allow overwriting any existing files.
+  -t THREADS --threads=THREADS  Number of threads to use for downloading
+                                distributed files. `-1` allocates a thread per
+                                part-file while `1` disables parallelization
+                                altogether [default: -1].
   -v --version                  Show version and exit.
 
 Examples:
   hdfs -a prod /user/foo
   hdfs --read logs/1987-03-23 >>logs
   hdfs --write -o data/weights.tsv <weights.tsv
+  hdfs --download features.avro dat/
 
 HdfsCLI exits with return status 1 if an error occurred and 0 otherwise.
 
@@ -53,11 +50,11 @@ HdfsCLI exits with return status 1 if an error occurred and 0 otherwise.
 from docopt import docopt
 from hdfs import __version__
 from hdfs.client import Client
-from hdfs.util import catch, HdfsError, hsize, htime
+from hdfs.util import Config, HdfsError, catch, hsize, htime
 from json import dumps
 from time import time
+import logging as lg
 import sys
-import os
 
 
 def infos(client, hdfs_path, depth, json):
@@ -100,6 +97,9 @@ def read(reader, size, message, _out=sys.stdout, _err=sys.stderr):
   :param _out: Performance caching.
   :param _err: Performance caching.
 
+  If the output is piped to something else than a TTY, progress percentages
+  are displayed.
+
   """
   if _out.isatty():
     for chunk in reader:
@@ -123,32 +123,43 @@ def read(reader, size, message, _out=sys.stdout, _err=sys.stderr):
 @catch(HdfsError)
 def main():
   """Entry point."""
+  # arguments parsing first for quicker feedback on invalid arguments
   args = docopt(__doc__, version=__version__)
+  # set up logging
+  logger = lg.getLogger('hdfs')
+  logger.setLevel(lg.DEBUG)
+  handler = Config().get_file_handler()
+  if handler:
+    logger.addHandler(handler)
+  # set up client and fix arguments
   client = Client.from_alias(args['--alias'])
-  rpath = args['PATH'] or ''
-
-  int_args = {}
-  for p in ('--depth', '--threads'):
+  rpath = args['RPATH'] or ''
+  for option in ('--depth', '--threads'):
     try:
-      int_args[p] = int(args[p])
+      args[option] = int(args[option])
     except ValueError:
-      raise HdfsError('Invalid `%s` option: %r.', p, args[p])
-
-  if args['--write']:
+      raise HdfsError('Invalid `%s` option: %r.', option, args[option])
+  # run command
+  if args['--log']:
+    if handler:
+      sys.stdout.write('%s\n' % (handler.baseFilename, ))
+    else:
+      raise HdfsError('No log file active.')
+  elif args['--write']:
     reader = (line for line in sys.stdin) # doesn't work with stdin, why?
     client.write(rpath, reader, overwrite=args['--overwrite'])
   elif args['--read']:
-    parts = client.parts(rpath)
-    for index, path in enumerate(parts):
-      size = client.status(path)['length']
-      message = '%s\t%s\t[%s/%s]' % (hsize(size), path, index + 1, len(parts))
-      read(client.read(path), size, message)
+    size = client.status(rpath)['length']
+    read(client.read(rpath), size, '%s\t' % (rpath, ))
   elif args['--download']:
-    status_dict = client.status(rpath)
-    client.download(rpath, args['LOCALPATH'], overwrite=args['--overwrite'], 
-      num_threads=int_args['--threads'])
+    client.download(
+      rpath,
+      args['LPATH'],
+      overwrite=args['--overwrite'],
+      n_threads=args['--threads']
+    )
   else:
-    infos(client, rpath, int_args['--depth'], args['--json'])
+    infos(client, rpath, args['--depth'], args['--json'])
 
 if __name__ == '__main__':
   main()
