@@ -15,6 +15,7 @@ import os.path as osp
 import posixpath
 import re
 import requests as rq
+import time
 
 
 _logger = lg.getLogger(__name__)
@@ -468,6 +469,13 @@ class Client(object):
           move(_temp_path, _local_path) # consistent with `mv` behavior
         self._logger.info('Downloaded %s to %s.', _hdfs_path, _local_path)
 
+    def _delayed_download(indexed_paths):
+      """Download and atomic swap, with delay to avoid replay errors."""
+      file_n, paths = indexed_paths
+      # Sleep some milliseconds so that authentication time stamps are not same
+      time.sleep(0.01 * file_n)
+      _download(paths)
+
     status = self.status(hdfs_path)
     if status['type'] == 'FILE':
       self._logger.debug(
@@ -504,7 +512,7 @@ class Client(object):
               'Starting parallel download using %s threads.', n_threads
             )
             p = ThreadPool(n_threads)
-            p.map(_download, part_paths)
+            p.map(_delayed_download, enumerate(part_paths))
           else:
             self._logger.debug('Starting synchronous download.')
             map(_download, part_paths)
